/*
 * UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 * MIAGE - UFR 27
 */
package review.exercices;

/**
 * Classe représentant un tableau d'entiers, dans lequel l'accès aux cases
 * est directe et "aléatoire" (l'utilisateur décide de son remplissage).
 * Pour le "fun", la classe est réalisée sans l'usage des Collections (ArrayList et cia).
 * L'idée est montrer à quel point le framework Collection est intéressant afin
 * d'éviter de nombreuses bugs.
 * @author Manuele Kirsch Pinheiro <kirschpm@gmail.com>
 */
public class TableauEntier {
    /** taille de tableau par défaut */
    public static int DEFAULT_SIZE=10; 
    
    /** taille du tableau */
    private int taille;
    /** tableau proprement parlé */
    private int[] tableau;
    /** tableau d'états : il garde si une case est vide ou pas */
    private boolean[] etat;

    
    public TableauEntier(int taille) {
        if (taille>0)
            this.taille=taille;
        else
            this.taille = DEFAULT_SIZE;
        
        this.tableau = new int[this.taille];
        this.etat = new boolean[this.taille];
        
        //on initialise ts les états en false, car les cases sont vides
        for (int i = 0; i < this.taille; i++) {
            this.etat[i] = false;
        }
    }

    /**
     * ajoute une nouvelle valeur à une case du tableau. Ceci n'est possible
     * que si la case en question est vide. Si la case est occupée, ou que la
     * position (indice) est invalide, la méthode ajouter retournera faux et ne
     * changera pas le tableau. 
     * 
     * @param val  valeur à ajouter
     * @param pos  indice dans lequel on veut ajouter la valeur
     * @return true si on a pu ajouter la valeur à la position demandée
     *         false si l'indice est invalide ou si la case était déjà occupée
     */
    public boolean ajouter(int val, int pos) {
        boolean ok = false;
        if (pos >= 0 && pos < taille && !etat[pos]) {
            tableau[pos] = val;
            etat[pos] = true;
            ok = true;
        }
        return ok;
    }

    /**
     * récupère la valeur stockée dans l'indice (position) indiqué en paramètre.
     * Si la position renseignée est invalide (inférieur à zéro ou supérieur à
     * taille-1), ou encore si la case est vide, la méthode recuperer va lancer
     * une exception de type IndexOutOfBoundsException. 
     * 
     * @throws IndexOutOfBoundsException si position invalide ou inoccupée
     * @param pos   indice de la position recherchée
     * @return int  valeur récupérée dans le tableau à cette position 
     */
    public int recuperer(int pos) throws IndexOutOfBoundsException{
        
        if (pos >= 0 && pos < taille && etat[pos]) {
            //la position est valide et occupée, on retourne alors sa valeur
            return tableau[pos];
        } else {
            //la position est invalide ou inoccupee, on lance alors une exception
            throw new IndexOutOfBoundsException("Position " + pos
                    + " invalide ou inoccupée");
        }

    }

    /**
     * supprime la valeur de la case indiquée.
     * @param pos indice de la case à supprimer
     */
    public void supprimer(int pos) {
        if (pos>=0 && pos<taille && etat[pos]) {
            //postion valide et occupe, on la libère
            tableau[pos]=0;
            etat[pos]=false;
        }
    }

    /**
     * indique si une case, à une position donnée, est occupée ou libre
     * @param pos indice de la position qu'on veut tester
     * @return true si la position est occupée, false sinon
     */
    public boolean estOccupee(int pos) {
        if (pos>=0 && pos<taille) 
            return etat[pos];
        else 
            return true;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("[");
        
        //on met la valeur si la case est occupée, un '-' si elle est vide        
        for (int i=0; i<taille; i++) {
            if (etat[i]) { //occupee
                sb.append(tableau[i]);
                sb.append(" ");
            }
            else 
                sb.append("- ");
        }            
        sb.append("]");
        return sb.toString();
    }
}