/*
 * UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 * MIAGE - UFR 27
 */

package review.exercices.business;

import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import review.business.Employee;

/**
 * Contrôleur capable de gérer plusieurs vue, notamment les vues AbstractDepartmentView. 
 * @author kirsch
 */
public class ConcreteDepartmentControler implements DepartmentControler {

    private ArrayList<DepartmentView> views;

    private DepartmentModel model;

    public ConcreteDepartmentControler(DepartmentModel model) {
        this.model = model;
        this.views = new ArrayList<DepartmentView>();
    }


    public void notifyAddEmployee(String name, float salary, Date hire) {
        Employee newE = new Employee (name, salary, hire);
        this.model.addEmployee(newE);
    }

    public void notifyRemoveEmployee(String name) {
        Employee supE = this.model.getEmployee(name);
        if (supE != null)
            this.model.removeEmployee(supE);
        /* else {
         * //ICI ON DEVAIT LANCE UNE EXCEPTION OU LANCER UNE NOUVELLE VUE
         * //AFIN QUE L'UTILISATEUR SOIT INFORMER PAR L'INTERFACE GRAPHIQUE
         * //AVEC UNE MESSAGE D'ERREUR APPROPRIE
         * }
         */
    }

    public List getEmployeeNames() {
        ArrayList<String> eNames = new ArrayList();
        Iterator<Employee> iter = this.model.employees();
        while (iter.hasNext())
            eNames.add(iter.next().getName());

        return eNames;
    }

    /**
     * ajoute une nouvelle vue à ce contrôleur. 
     * S'il s'agit d'une AbstractDepartmentView, il l'abonnera aux événements
     * générés par son modèle. 
     * @param view (AbstractDepartmentView) vue à enregistrer
     * @see AbstractDepartmentView
     */
    public void addDepartmentView(DepartmentView view) {
        this.views.add(view);
        //Seulement les AbstractDepartmentView sont DepartmentListener
        if (view instanceof AbstractDepartmentView) {
            this.model.addDepartmentListner((AbstractDepartmentView) view);
        }
    }

    /**
     * supprime  une  vue de ce contrôleur. 
     * S'il s'agit d'une AbstractDepartmentView, il la "désabonnera" aux événements
     * générés par son modèle. 
     * @param view (AbstractDepartmentView) vue à désabonner 
     * @see AbstractDepartmentView
     */
    public void removeDepartmentView(DepartmentView view) {
        //Seulement les AbstractView sont DepartmentListener
        if (view instanceof AbstractDepartmentView) {
            this.model.removeDepartmentListener((AbstractDepartmentView) view);
        }
        this.views.remove(view);
    }

    public void diplayAll() {
        for (DepartmentView v: this.views) {
            v.setVisible(true);
        }
    }

    public void closeAll() {
        this.model.save();
        System.exit(0);
    }

}
