/*
 * UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 * MIAGE - UFR 27
 */
package review.exercices.business;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import javax.swing.JOptionPane;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import review.business.Employee;

/**
 * Controler capable de gérer deux vue, une NoListenerFormEmployee et une
 * NoListenerListEmployees.
 *
 * @author Manuele Kirsch Pinheiro <kirschpm@gmail.com>
 */
public class ListenerDepartmentControler implements DepartmentControler,
        FullDepartmentListener, ActionListener, ListSelectionListener {

    private NoListenerFormEmployee formView;
    private NoListenerListEmployees listView;
    private FullDataBaseDepartmentModel model;

    public ListenerDepartmentControler(FullDataBaseDepartmentModel model) {
        this.model = model;
        this.model.addFullDepartmentListener(this);
        this.model.addDepartmentListner(this);
    }

    @Override
    public void notifyAddEmployee(String name, float salary, Date hire) {
        Employee newE = new Employee(name, salary, hire);
        this.model.addEmployee(newE);
    }

    @Override
    public void notifyRemoveEmployee(String name) {
        Employee supE = this.model.getEmployee(name);
        if (supE != null) {
            this.model.removeEmployee(supE);
        }
    }

    @Override
    public List getEmployeeNames() {
        ArrayList<String> eNames = new ArrayList();
        Iterator<Employee> iter = this.model.employees();
        while (iter.hasNext()) {
            eNames.add(iter.next().getName());
        }

        return eNames;
    }

    /**
     * ce contrôleur n'est capable de manipuler deux vues du type
     * NoListenerFormEmployee et NoListenerListEmployees. Tous les autres types
     * de vues seront ignorées. L'ajout d'une nouvelle vue remplace l'existante.
     *
     * @param view (NoListenerFormEmployee | NoListenerListEmployees ) vue
     * @exception UnsupportedOperationException si un autre type de vue est
     * ajouté
     */
    @Override
    public void addDepartmentView(DepartmentView view) {
        if (view instanceof NoListenerFormEmployee) {
            this.formView = (NoListenerFormEmployee) view;
        } else if (view instanceof NoListenerListEmployees) {
            this.listView = (NoListenerListEmployees) view;
        } else {
            throw new UnsupportedOperationException("Not supported yet.");
        }
        this.setupDepartmentView((AbstractNoListenerDepartmentView) view);
    }

    protected void setupDepartmentView(AbstractNoListenerDepartmentView view) {
        view.setDepartmentControler(this);
    }

    @Override
    public void removeDepartmentView(DepartmentView view) {
        if (view instanceof NoListenerFormEmployee) {
            this.formView = null;
        } else if (view instanceof NoListenerListEmployees) {
            this.listView = null;
        }
    }

    @Override
    public void diplayAll() {
        if (this.formView != null) this.formView.setVisible(true);
        if (this.listView != null) this.listView.setVisible(true);
    }

    @Override
    public void closeAll() {
        if (this.formView != null) this.formView.setVisible(false);
        if (this.listView != null) this.listView.setVisible(false);
        this.model.save();
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        System.out.println("action performed");
        if (e.getActionCommand().equals(NoListenerFormEmployee.OK_COMMAND)) {
            HashMap<String, Object> data = this.formView.getFieldData();
            if (!data.isEmpty()) {
                System.out.println("adding " + data.get(NoListenerFormEmployee.NAME_FIELD));
                this.notifyAddEmployee((String) data.get(NoListenerFormEmployee.NAME_FIELD),
                        (Float) data.get(NoListenerFormEmployee.SALARY_FIELD),
                        (Date) data.get(NoListenerFormEmployee.HIRE_DATE_FIELD));
            }
        } else if (e.getActionCommand().equals(NoListenerFormEmployee.REMOVE_COMMAND)) {
            HashMap<String, Object> data = this.formView.getFieldData();
            if (!data.isEmpty()) {
                System.out.println("removing " + (String) data.get(NoListenerFormEmployee.NAME_FIELD));
                this.notifyRemoveEmployee((String) data.get(NoListenerFormEmployee.NAME_FIELD));
            }
        }


    }

    @Override
    public void valueChanged(ListSelectionEvent evt) {
        System.out.println("value changed");
        if (evt.getValueIsAdjusting() == false) {
            String name = this.listView.getSelectedEmployee();
            System.out.println("selected "+name);
            if (!name.isEmpty()) {
                Employee e = this.model.getEmployee(name);
                if (e != null) {
                    this.formView.setFields(e.getName(), e.getSalary(), e.getHireDay());
                }
            }
        }
    }

    @Override
    public void employeeChanged(FullDepartmentChangedEvent evt) {
        Employee e = evt.getAffectedEmployee();
        if (e != null) {
            StringBuilder sb = new StringBuilder();
            sb.append("Employee ");
            sb.append(e.getName());
            sb.append(" updated");
            JOptionPane.showMessageDialog(null, sb.toString(), "Information", JOptionPane.INFORMATION_MESSAGE);
        }
    }

    @Override
    public void employeeRemoved(FullDepartmentChangedEvent evt) {
        Employee e = evt.getAffectedEmployee();
        if (e != null) {
            StringBuilder sb = new StringBuilder();
            sb.append("Employee ");
            sb.append(e.getName());
            sb.append(" removed");
            JOptionPane.showMessageDialog(null, sb.toString(), "Information", JOptionPane.INFORMATION_MESSAGE);
        }
        
        if (this.listView != null) this.listView.loadNames();
        
    }

    @Override
    public void employeeAdded(FullDepartmentChangedEvent evt) {
        //do nothing
    }

    @Override
    public void departmentChanged(DepartmentChangedEvent evt) {
        if (this.listView != null) this.listView.loadNames();
    }
}
