/*
 UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 MIAGE - UFR 27
 Cours ISI5 / INF2 - Developpement d'Interface

 */

package review.ihm.volumeapplication;

import java.util.ArrayList;
import java.util.List;

/**
 * Example d'usage du modele MVC
 * Cette classe definit le controler pour modele de volume.
 *
 * Example base sur Baptiste Wicht, <b>"Implémentation du pattern MVC"</b>,
 * 24 Avril 2007 (derniere visite le 29 Janvier 2009).
 * @see http://baptiste-wicht.developpez.com/tutoriel/conception/mvc/
 * @author kirsch
 */
public class VolumeController {

    public VolumeController(VolumeModel model) {
        this.model = model;
        this.views = new ArrayList<VolumeView>();
    }

    public VolumeModel getModel() {
        return model;
    }

    public void setModel(VolumeModel model) {
        this.model = model;
    }


    /**
     * ce methode est utilise par les vue pour informer lors des
     * demandes (de l'utilisateur) de modification du volume.
     * @param newVolume nouveau valeur de volume
     */
    public void notifyVolumeChange(int newVolume) {
        this.model.setVolume(newVolume);
    }

     
    public void addView (VolumeView view) {
        this.views.add(view);
        this.model.addVolumeListener(view);
    }

    public void removeView (VolumeView view) {
        this.views.remove(view);
        this.model.removeVolumeListener(view);
     }

    public void displayViews() {
        for (VolumeView aView: this.views) {
            aView.display();
        }
     }

    public void closeViews() {
        for (VolumeView aView: this.views) {
            aView.close();
        }
    }

    private VolumeModel model;
    private List<VolumeView> views;
}
