/*
 * UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 * MIAGE - UFR 27
 */
package review.structures;

/**
 * Main illustrant l'usage de la classe TableauObjetBugged et le problème de
 * manipuler juste des instances de la classe Object, sans utiliser les
 * génériques. La classe TableauObject n'étant pas paramétrée, il est facile de
 * se retrouver avec une exception, ce que démontre cette classe
 * MainTableauObjects
 *
 * @author Manuele Kirsch Pinheiro <kirschpm@gmail.com>
 * @see TableauObjects
 */
public class MainTableauObjets {

    /**
     * exemple de l'usage d'une classe qui utilise la généricité :
     * c'est le compilateur Java lui-même qui contrôle si on utilise le bon type
     * de données
     */
    public static void avecGenericite() {
        TableauObjet<Integer> tab = new TableauObjet<Integer>(3);
        tab.fillCase(0, new Integer(5));
        
        //le compilateur ne nous laisse plus faire ça
        //puisque la classe est "typée" Integer 
        //tab.fillCase(2, new String("5")); 
        
        System.out.println(tab);
        
        for (int i = 0; i < tab.size(); i++) {
            //et lorsqu'on va utiliser, plus besoin de typecast !
            Integer o = tab.getCase(i);
            if (o != null) {
                System.out.println(o.toString());
            }
        }
    }
    
    /**
     * exemple de l'usage d'une classe qui n'utilise pas la généricité
     * on est sujet à des exceptions par une mauvaise usage
     */
    public static void sansGenericite() {
        TableauObjetBugged tab = new TableauObjetBugged(3);
        tab.fillCase(0, new Integer(5));
        tab.fillCase(2, new String("5")); //le prob est ici : rien nous dit qu'on
        //ne doit pas mélanger Integer et string
        
        System.out.println(tab);
        
        for (int i = 0; i < tab.size(); i++) {
            //et lorsqu'on va utiliser, ça bug !
            Integer o = (Integer) tab.getCase(i);
            if (o != null) {
                System.out.println(o.toString());
            }
        }
    }
     

    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        System.out.println("Avec l'usage de généricité...");
        avecGenericite();
        
        System.out.println("Sans l'usage de généricité... ");
        sansGenericite();
        
    }
}
