/*
 * UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 * MIAGE - UFR 27
 */
package review.structures;

/**
 * Classe représentant un tableau d'objets, dans lequel l'accès aux cases
 * est directe et limité à une seule classe d'objets, quelque soit cette classe.  
 * Il s'agit d'un exemple d'usage des génériques en Java. 
 * @author Manuele Kirsch Pinheiro <kirschpm@gmail.com>
 */
public class TableauObjet<T> {
    /** taille de tableau par défaut */
    public static int DEFAULT_SIZE=10; 
    private T[] tableau;
    private int taille;

    /**
     * construction d'un objet TableauObjet d'une taille donnée. 
     * Si celle-ci ne correspond pas à une taille valable (size<0 par exemple), 
     * le tableau aura une taille par défaut. 
     * @param size taille du nouveau tableau d'objets
     * @see #DEFAULT_SIZE
     */
    public TableauObjet(int size) {
        if (size>0)
            this.taille=size;
        else
            this.taille = DEFAULT_SIZE;
        
        //impossible ! limitation java
        //this.tableau = new T[this.taille];
        this.tableau = (T[])new Object[this.taille];
    }

    public void fillCase(int pos, T value) {
        if (pos>=0 && pos<this.taille) {
            this.tableau[pos]=value;
        }
    }

    public T getCase(int pos) {
        if (pos>=0 && pos<this.taille) 
            return this.tableau[pos];
        else
            return null;
    }

    public void clearCase(int pos) {
        if (pos>=0 && pos<this.taille) 
            this.tableau[pos]=null;
    }

    public int size() {
        return this.taille;
    }
    
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{ ");
        for (Object o : this.tableau) {
            sb.append(o);
            sb.append(' ');
        }
        sb.append('}');
        return sb.toString();
    }
}